io_classifier: Sort Catch Numbers Into Species Categories

Description Usage Arguments

View source: R/io_classifier.R

Description

This function uses itis_reclassify(), developed by Emily Markowitz, to create species category classifications and then sorts catch numbers into those classifications.

Usage

1
2
3
4
5
6
7
io_classifier(
  data,
  species = Comm.Catch.Spp.List,
  year = NA,
  recall = T,
  tsn = NULL
)

Arguments

data

A data frame that includes catch numbers in dollars and TSN.

year

A numeric variable that can be used to filter for a specific year. Defaults to NA, which returns all years.

tsn

A dataset that can be used in place of the API call. Defaults to NULL

list

A list of lists that includes categories at the top level and TSN numbers at the second level. Defaults to Comm.Catch.Spp.List.

recal

A binary variable that determines whether the API should be queried or a default value used. Defaults to TRUE


AlexRichardson-NOAA/feusIO2 documentation built on Dec. 17, 2021, 7:50 a.m.