io_cleaner: Clean the Output From the IO Model

Description Usage Arguments

View source: R/io_cleaner.R

Description

This function presents the output from io_calculator() in a variety of specifiable formats.

Usage

1
io_cleaner(impact, format = "national", xlsx = F, fp = fips, maxyr = 2018)

Arguments

impact

A data frame that was output by io_calculator().

format

A string variable with several options for specifying output format.

xlsx

A boolean variable that exports the output as tabs in an xlsx file if True.

fp

A data frame containing state names and fips codes. Defaults to standard with EFL = 12 and WFL = 12.5.

maxyr

The catch year - only used for FEUS.


AlexRichardson-NOAA/feusIO2 documentation built on Dec. 17, 2021, 7:50 a.m.