View source: R/io_classifier.R
This function uses itis_reclassify(), developed by Emily Markowitz, to create species category classifications and then sorts catch numbers into those classifications.
1 2 3 4 5 6 7 | io_classifier(
data,
species = Comm.Catch.Spp.List,
year = NA,
recall = T,
tsn = NULL
)
|
data |
A data frame that includes catch numbers in dollars and TSN. |
year |
A numeric variable that can be used to filter for a specific year. Defaults to NA, which returns all years. |
tsn |
A dataset that can be used in place of the API call. Defaults to NULL |
list |
A list of lists that includes categories at the top level and TSN numbers at the second level. Defaults to Comm.Catch.Spp.List. |
recal |
A binary variable that determines whether the API should be queried or a default value used. Defaults to TRUE |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.