This function presents the output from io_calculator() in a variety of specifiable formats.
1 | io_cleaner(impact, format = "national", xlsx = F, fp = fips, maxyr = 2018)
|
impact |
A data frame that was output by io_calculator(). |
format |
A string variable with several options for specifying output format. |
xlsx |
A boolean variable that exports the output as tabs in an xlsx file if True. |
fp |
A data frame containing state names and fips codes. Defaults to standard with EFL = 12 and WFL = 12.5. |
maxyr |
The catch year - only used for FEUS. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.